@@ -1,3 +1,8 @@
+#
+# This program source code file is part of KiCad, a free EDA CAD application.
+#
+# Copyright (C) 2021 KiCad Developers, see AUTHORS.txt for contributors.
+#
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation; either version 2 of the License, or
@@ -22,7 +27,7 @@ import math
 class FootprintWizard(pcbnew.FootprintWizardPlugin):
     """!
     A class to simplify many aspects of footprint creation, leaving only
-    the foot-print specific routines to the wizards themselves.
+    the footprint specific routines to the wizards themselves.
 
     Inherit this class to make a new wizard.
 
@@ -100,7 +105,7 @@ class FootprintWizard(pcbnew.FootprintWizardPlugin):
         """
 
         self.buildmessages = ""
-        self.module = pcbnew.MODULE(None)  # create a new module
+        self.module = pcbnew.FOOTPRINT(None)  # create a new module
 
         # Perform default checks on all parameters
         for p in self.params:
@@ -136,15 +141,15 @@ class FootprintWizard(pcbnew.FootprintWizardPlugin):
         self.module.SetValue(self.GetValue())
         self.module.SetReference("%s**" % self.GetReferencePrefix())
 
-        fpid = pcbnew.LIB_ID(self.module.GetValue())  # the name in library
+        fpid = pcbnew.LIB_ID("", self.module.GetValue())  # the lib name  (empty) and the name in library
         self.module.SetFPID(fpid)
 
         self.SetModule3DModel()  # add a 3D module if specified
 
         thick = self.GetTextThickness()
 
-        self.module.Reference().SetThickness(thick)
-        self.module.Value().SetThickness(thick)
+        self.module.Reference().SetTextThickness(thick)
+        self.module.Value().SetTextThickness(thick)
 
         self.BuildThisFootprint()  # implementer's build function
 
@@ -334,8 +339,8 @@ class FootprintWizardDrawingAids:
         This is performed by a translate-to-origin, flip, translate-
         back sequence.
 
-        @param x: the x co-ordinate of the flip point
-        @param y: the y co-ordinate of the flip point
+        @param x: the x coordinate of the flip point
+        @param y: the y coordinate of the flip point
         @param flip: one of flipNone, flipX, flipY, flipBoth
         @param push: add this transform to the current stack
         @return the generated transform matrix
@@ -379,8 +384,8 @@ class FootprintWizardDrawingAids:
         This is performed by a translate-to-origin, rotate, translate-
         back sequence
 
-        @param x: the x co-ordinate of the rotation centre
-        @param y: the y co-ordinate of the rotation centre
+        @param x: the x coordinate of the rotation centre
+        @param y: the y coordinate of the rotation centre
         @param rot: the rotation angle in degrees
         @param push: add this transform to the current stack
         @return the generated transform matrix
@@ -425,17 +430,17 @@ class FootprintWizardDrawingAids:
         Return a point (x, y) transformed by the given matrix, or if
         that is not given, the drawing context transform
 
-        @param x: the x co-ordinate of the point to transform
-        @param y: the y co-ordinate of the point to transform
+        @param x: the x coordinate of the point to transform
+        @param y: the y coordinate of the point to transform
         @param mat: the transform matrix to use or None to use the current DC's
-        @return: the transformed point as a wxPoint
+        @return: the transformed point as a VECTOR2I
         """
 
         if not mat:
             mat = self.dc['transform']
 
-        return pcbnew.wxPoint(x * mat[0] + y * mat[1] + mat[2],
-                              x * mat[3] + y * mat[4] + mat[5])
+        return pcbnew.VECTOR2I( (int)(x * mat[0] + y * mat[1] + mat[2]),
+                                (int)(x * mat[3] + y * mat[4] + mat[5]) )
 
     def SetLineThickness(self, lineThickness):
         """!
@@ -449,7 +454,7 @@ class FootprintWizardDrawingAids:
     def SetLineTickness(self, lineThickness):
         """!
         Old version of SetLineThickness.
-        Does the same thing, but is is only here for compatibility with old
+        Does the same thing, but is only here for compatibility with old
         scripts.
         Set the current pen lineThickness used for subsequent drawing
         operations
@@ -481,7 +486,7 @@ class FootprintWizardDrawingAids:
         """!
         Draw a line from (x1, y1) to (x2, y2)
         """
-        outline = pcbnew.EDGE_MODULE(self.module)
+        outline = pcbnew.FP_SHAPE(self.module)
         outline.SetWidth(self.GetLineThickness())
         outline.SetLayer(self.GetLayer())
         outline.SetShape(pcbnew.S_SEGMENT)
@@ -496,14 +501,14 @@ class FootprintWizardDrawingAids:
         If filled is true, the thickness and radius of the line will be set
         such that the circle appears filled
 
-        @param x: the x co-ordinate of the arc centre
-        @param y: the y co-ordinate of the arc centre
+        @param x: the x coordinate of the arc centre
+        @param y: the y coordinate of the arc centre
         @param r: the circle's radius
         @param filled: True to draw a filled circle, False to use the current
                        DC line thickness
         """
 
-        circle = pcbnew.EDGE_MODULE(self.module)
+        circle = pcbnew.FP_SHAPE(self.module)
         start = self.TransformPoint(x, y)
 
         if filled:
@@ -518,7 +523,17 @@ class FootprintWizardDrawingAids:
         circle.SetStartEnd(start, end)
         self.module.Add(circle)
 
-    def Arc(self, cx, cy, sx, sy, a):
+    def MyCmp(self, n1, n2):
+        """
+        replace the cmp() of python2
+        """
+        if n1 < n2:
+            return -1
+        if n1 > n2:
+            return 1
+        return 0
+
+    def Arc(self, cx, cy, sx, sy, angle):
         """!
         Draw an arc based on centre, start and angle
 
@@ -527,35 +542,37 @@ class FootprintWizardDrawingAids:
         Note that this won't work properly if the result is not a
         circular arc (e.g. a horizontal scale)
 
-        @param cx: the x co-ordinate of the arc centre
-        @param cy: the y co-ordinate of the arc centre
-        @param sx: the x co-ordinate of the arc start point
-        @param sy: the y co-ordinate of the arc start point
-        @param a: the arc's central angle (in deci-degrees)
+        @param cx: the x coordinate of the arc centre
+        @param cy: the y coordinate of the arc centre
+        @param sx: the x coordinate of the arc start point
+        @param sy: the y coordinate of the arc start point
+        @param angle: the arc's central angle (in deci-degrees)
         """
-        circle = pcbnew.EDGE_MODULE(self.module)
-        circle.SetWidth(self.dc['lineThickness'])
+        arc = pcbnew.FP_SHAPE(self.module)
+        arc.SetShape(pcbnew.SHAPE_T_ARC)
+        arc.SetWidth(self.dc['lineThickness'])
 
         center = self.TransformPoint(cx, cy)
         start = self.TransformPoint(sx, sy)
 
-        circle.SetLayer(self.dc['layer'])
-        circle.SetShape(pcbnew.S_ARC)
+        arc.SetLayer(self.dc['layer'])
 
         # check if the angle needs to be reverse (a flip scaling)
-        if cmp(self.dc['transform'][0], 0) != cmp(self.dc['transform'][4], 0):
-            a = -a
+        if self.MyCmp(self.dc['transform'][0], 0) != self.MyCmp(self.dc['transform'][4], 0):
+            angle = -angle
 
-        circle.SetAngle(a)
-        circle.SetStartEnd(center, start)
-        self.module.Add(circle)
+        arc.SetCenter(center)
+        arc.SetStart(start)
+        arc.SetArcAngleAndEnd(angle, True)
+        arc.SetLocalCoord()
+        self.module.Add(arc)
 
     def HLine(self, x, y, l):
         """!
         Draw a horizontal line from (x,y), rightwards
 
-        @param x: line start x co-ordinate
-        @param y: line start y co-ordinate
+        @param x: line start x coordinate
+        @param y: line start y coordinate
         @param l: line length
         """
         self.Line(x, y, x + l, y)
@@ -564,8 +581,8 @@ class FootprintWizardDrawingAids:
         """!
         Draw a vertical line from (x1,y1), downwards
 
-        @param x: line start x co-ordinate
-        @param y: line start y co-ordinate
+        @param x: line start x coordinate
+        @param y: line start y coordinate
         @param l: line length
         """
         self.Line(x, y, x, y + l)
@@ -575,8 +592,8 @@ class FootprintWizardDrawingAids:
         Draw a polyline, optionally mirroring around the given points
 
         @param pts: list of polyline vertices (list of (x, y))
-        @param mirrorX: x co-ordinate of mirror point (None for no x-flip)
-        @param mirrorY: y co-ordinate of mirror point (None for no y-flip)
+        @param mirrorX: x coordinate of mirror point (None for no x-flip)
+        @param mirrorY: y coordinate of mirror point (None for no y-flip)
         """
 
         def _PolyLineInternal(pts):
@@ -616,14 +633,13 @@ class FootprintWizardDrawingAids:
         @param orientation_degree: text orientation in degrees
         """
 
-        text_size = pcbnew.wxSize(size, size)
+        text_size = pcbnew.VECTOR2I(size, size)
 
         self.module.Reference().SetPos0(self.TransformPoint(x, y))
         self.module.Reference().SetPosition(
             self.module.Reference().GetPos0())
         self.module.Reference().SetTextSize(text_size)
-        # internal angles are in 0.1 deg
-        self.module.Reference().SetTextAngle(orientation_degree * 10)
+        self.module.Reference().SetTextAngle( pcbnew.EDA_ANGLE( orientation_degree, pcbnew.DEGREES_T ) )
 
     def Value(self, x, y, size, orientation_degree=0):
         """!
@@ -634,22 +650,21 @@ class FootprintWizardDrawingAids:
         @param size: the text size (in both directions)
         @param orientation_degree: text orientation in degrees
         """
-        text_size = pcbnew.wxSize(size, size)
+        text_size = pcbnew.VECTOR2I(size, size)
 
         self.module.Value().SetPos0(self.TransformPoint(x, y))
         self.module.Value().SetPosition(self.module.Value().GetPos0())
         self.module.Value().SetTextSize(text_size)
         self.module.Value().SetLayer(self.DefaultTextValueLayer())
-        # internal angles are in 0.1 deg
-        self.module.Value().SetTextAngle(orientation_degree * 10)
+        self.module.Value().SetTextAngle( pcbnew.EDA_ANGLE( orientation_degree, pcbnew.DEGREES_T ) )
 
     def Box(self, x, y, w, h):
         """!
         Draw a rectangular box, centred at (x,y), with given width and
         height
 
-        @param x: the x co-ordinate of the box's centre
-        @param y: the y co-ordinate of the box's centre
+        @param x: the x coordinate of the box's centre
+        @param y: the y coordinate of the box's centre
         @param w: the width of the box
         @param h: the height of the box
         """
@@ -668,8 +683,8 @@ class FootprintWizardDrawingAids:
         at the top
         Notch height is measured from the top of the circle radius
 
-        @param x: the x co-ordinate of the circle's centre
-        @param y: the y co-ordinate of the circle's centre
+        @param x: the x coordinate of the circle's centre
+        @param y: the y coordinate of the circle's centre
         @param r: the radius of the circle
         @param notch_w: the width of the notch
         @param notch_h: the height of the notch
@@ -702,8 +717,8 @@ class FootprintWizardDrawingAids:
         """!
         Draw a box with a notch in the centre of the top edge
 
-        @param x: the x co-ordinate of the circle's centre
-        @param y: the y co-ordinate of the circle's centre
+        @param x: the x coordinate of the circle's centre
+        @param y: the y coordinate of the circle's centre
         @param w: the width of the box
         @param h: the height of the box
         @param notchW: the width of the notch
@@ -737,8 +752,8 @@ class FootprintWizardDrawingAids:
         """!
         Draw a box with a diagonal at the top left corner.
 
-        @param x: the x co-ordinate of the circle's centre
-        @param y: the y co-ordinate of the circle's centre
+        @param x: the x coordinate of the circle's centre
+        @param y: the y coordinate of the circle's centre
         @param w: the width of the box
         @param h: the height of the box
         @param setback: the set-back of the diagonal, in both x and y
@@ -764,8 +779,8 @@ class FootprintWizardDrawingAids:
         """!
         Draw a box with an opening at the top left corner
 
-        @param x: the x co-ordinate of the circle's centre
-        @param y: the y co-ordinate of the circle's centre
+        @param x: the x coordinate of the circle's centre
+        @param y: the y coordinate of the circle's centre
         @param w: the width of the box
         @param h: the height of the box
         @param setback: the set-back of the opening, in both x and y
@@ -790,8 +805,8 @@ class FootprintWizardDrawingAids:
         """!
         Draw a box with rounded corners (i.e. a 90-degree circular arc)
 
-        :param x: the x co-ordinate of the box's centre
-        :param y: the y co-ordinate of the box's centre
+        :param x: the x coordinate of the box's centre
+        :param y: the y coordinate of the box's centre
         :param w: the width of the box
         :param h: the height of the box
         :param rad: the radius of the corner rounds
@@ -825,8 +840,8 @@ class FootprintWizardDrawingAids:
         """!
         Draw a box with chamfered corners.
 
-        :param x: the x co-ordinate of the box's centre
-        :param y: the y co-ordinate of the box's centre
+        :param x: the x coordinate of the box's centre
+        :param y: the y coordinate of the box's centre
         :param w: the width of the box
         :param h: the height of the box
         :param chamfer_x: the size of the chamfer set-back in the x direction
@@ -836,7 +851,7 @@ class FootprintWizardDrawingAids:
         x_left = x - w / 2
         y_top = y - h / 2
 
-        # x and y co-ordinates of inner edges of chamfers
+        # x and y coordinates of inner edges of chamfers
         x_inner = x_left + chamfer_x
         y_inner = y_top + chamfer_y
 
